Skip to contents

Control parameters for SuSiE RSS

Usage

susie_rss_control(
  mismatch_estimator = c("mle", "map"),
  mixture_reference_p = 5e-08,
  qc_eigen_tol_rel = 0.001,
  qc_eigen_tol_abs = 0,
  artifact_threshold = 0.1,
  sensitivity_threshold = 30,
  r_tol = 1e-08,
  check_input = FALSE,
  check_prior = TRUE
)

Arguments

mismatch_estimator

Estimator for the region-level mismatch variance: "mle" or "map".

mixture_reference_p

Two-sided reference P-value used to calibrate prior odds for R_mismatch = "eb_mix".

qc_eigen_tol_rel, qc_eigen_tol_abs

Relative and absolute cutoffs for low-eigenvalue directions in the RSS mismatch diagnostic.

artifact_threshold

Threshold in [0, 1] for the residual artifact score.

sensitivity_threshold

Threshold for credible-set Bayes-factor attenuation.

r_tol

Tolerance for positive-semidefinite matrix checks.

check_input

Whether to check summary-statistic matrices for positive semidefiniteness and consistency.

check_prior

Whether to check for an unreasonably large estimated prior variance relative to the marginal z-scores.

Value

A named list for the control argument of susie_rss.