Skip to contents

A simulated data set with 1,000 individuals and 5,000 variants, combining 3 sparse, 5 oligogenic and 15 polygenic non-zero effects. The response is generated under a linear regression model. This data set illustrates fine-mapping with SuSiE-ash and SuSiE-inf.

Format

unmappable_data is a list with the following elements:

X

Centered and scaled genotype matrix.

y

Simulated response.

beta

Simulated effect sizes.

h2g

Total proportion of variance in the response explained by the simulated effects.

See also

The “Fine-mapping with SuSiE-ash and SuSiE-inf” vignette.

Examples

data(unmappable_data)